"use strict";
const path = require("path");
const fs = require("fs");
const tmpdir = require('os-tmpdir');
const archiver_1 = require("./archiver");
const downloader_1 = require("./downloader");
const config_1 = require("./config");
const cleanup_all_1 = require("./cleanup-all");
const fail = (error) => {
    const message = error.message || error;
    console.error(message);
    process.exit(1);
};
if (process.argv.length < 2) {
    console.log('node ./package.js [win32|darwin|linux]');
    process.exit(-1);
}
const platform = process.argv[2];
const dir = tmpdir();
const root = path.join(dir, 'git-kitchen-sink');
if (!fs.existsSync(root)) {
    fs.mkdirSync(root);
}
config_1.Config.getConfig(platform)
    .then(config => {
    if (!config) {
        return Promise.reject(`unhandled platform found: ${platform}`);
    }
    else {
        const temporaryGitDirectory = path.join(root, platform, config.git.version);
        const destinationFile = `git-kitchen-sink-${platform}-v${config.outputVersion}.tgz`;
        const destination = path.join(root, destinationFile);
        return cleanup_all_1.cleanupAll(temporaryGitDirectory)
            .then(() => downloader_1.Downloader.downloadGit(config, root))
            .then(() => downloader_1.Downloader.downloadGitLFS(config, root))
            .then(() => archiver_1.Archiver.unpackAll(platform, config, root))
            .then(() => archiver_1.Archiver.create(temporaryGitDirectory, destination))
            .then(() => archiver_1.Archiver.output(destination));
    }
})
    .catch(err => fail(err));
//# sourceMappingURL=package.js.map